Learn R Programming

SoilR (version 1.0-0)

Model-class: Model

Description

serves as a fence to the interface of SoilR functions. So that later implementations can differ

Arguments

Objects from the Class

Objects can be created by calls of the form new(Model ...)