Learn R Programming

SoilR (version 1.0-3)

OnepModel14: Implementation of a one-pool C14 model

Description

This function creates a model for one pool. It is a wrapper for the more general function GeneralModel_14 that can handle an arbitrary number of pools.

Usage

OnepModel14(t, k, C0, In, xi = 1, FcAtm, lambda = -0.0001209681, 
    lag = 0, solver = deSolve.lsoda.wrapper)

Arguments

t
A vector containing the points in time where the solution is sought. It must be specified within the same period for which the Delta 14 C of the atmosphere is provided. The default period in the provided dataset C14
k
A scalar with the decomposition rate of the pool.
C0
A scalar containing the initial amount of carbon in the pool.
In
A scalar or a data.frame object specifying the amount of litter inputs by time.
xi
A scalar or a data.frame specifying the external (environmental and/or edaphic) effects on decomposition rates.
FcAtm
A Data Frame object consisting of a function describing the fraction of C_14 in per mille.
lambda
Radioactive decay constant. By default lambda=-0.0001209681 y^-1 . This has the side effect that all your time related data are treated as if the time unit was year.
lag
A (positive) scalar representing a time lag for radiocarbon to enter the system.
solver
A function that solves the system of ODEs. This can be euler or ode or any other user provided function with the same interface.

Value

  • A Model Object that can be further queried

See Also

OnepModel, TwopParallelModel14, TwopFeedbackModel14

Examples

Run this code
data(C14Atm_NH)
#Fc=TimeMap.from.Dataframe(C14Atm_NH)
years=seq(1901,2009,by=0.5)
LitterInput=700 

Ex=OnepModel14(t=years,k=1/10,C0=500, In=LitterInput, FcAtm=C14Atm_NH)
C14t=getSoilC14Fraction(Ex)

plot(C14Atm_NH,type="l",xlab="Year",ylab="Delta 14C (per mil)",xlim=c(1940,2010)) 
lines(years, C14t[,1], col=4)
legend("topright",c("Delta 14C Atmosphere", "Delta 14C in SOM"),lty=c(1,1),col=c(1,4),lwd=c(1,1),bty="n")

Run the code above in your browser using DataLab