Learn R Programming

SoilR (version 1.0-0)

RespirationCoefficients: RespirationCoefficients

Description

This function computes the respiration coefficients as function of time for all pools according to the given matrix A

Usage

RespirationCoefficients(A)

Arguments

A
A matrix valued function representing the model.

Value

  • A vector valued function of time containing the respiration coefficients for all pools.