ode and has the same interface.
It is much slower than ode and should probably be considered less capable in solving stiff ode systems.
However it has one main advantage, which consists in its simplicity.
It is quite easy to see what is going on inside it.
Whenever you don't trust your implementation of another (more efficient but probably also more complex)
ode solver, just compare the result to what this method computes.SoilR.euler(times, ydot, startValues)