Rdocumentation
powered by
Learn R Programming
SoilR (version 1.0-0)
TimeMap.new: TimeMap new
Description
This function is the basic constructor of the class TimeMap.
Usage
TimeMap.new(t_start, t_end, f)
Arguments
t_start
A number marking the begin of the time domain where the function is valid
t_end
A number the end of the time domain where the function is valid
f
The time dependent function definition (a function in R's sense)
Value
An object of class TimeMap that can be used to describe models.