Learn R Programming

SoilR (version 1.0-0)

fT.LandT: Effects of temperature on decomposition rates according to a function proposed by Lloyd and Taylor (1994)

Description

Calculates the effects of temperature on decomposition rates according to a function proposed by Lloyd and Taylor (1994).

Usage

fT.LandT(Temp)

Arguments

Temp
A scalar or vector containing values of soil temperature for which the effects on decomposition rates are calculated

Value

  • A scalar or a vector containing the effects of temperature on decomposition rates (unitless).

References

Lloyd, J., and J. A. Taylor (1994), On the Temperature Dependence of Soil Respiration, Functional Ecology, 8(3), 315-323.

Examples

Run this code
Temperature=0:50
plot(Temperature,fT.LandT(Temperature),type="l",ylab="f(T) (unitless)", 
     main="Effects of temperature on decomposition rates according to the Lloyd and Taylor function")

Run the code above in your browser using DataLab