ConstantOutFluxRate_by_PoolIndex: Generic constructor for the class with the same name
Description
Generic constructor for the class with the same name
Usage
ConstantOutFluxRate_by_PoolIndex(sourceIndex, rate_constant)
Arguments
- sourceIndex
index of the source pool
- rate_constant
rate of output flux