InternalFlux_by_PoolName: Generic constructor for the class with the same name
Description
Generic constructor for the class with the same name
Usage
InternalFlux_by_PoolName(func, sourceName, destinationName, src_to_dest)
Arguments
- func
function with flux rate
- sourceName
name of source pool
- destinationName
name of destination pool
- src_to_dest
source to destination