TimeMap-class: TimeMap S4 class
Description
defines a (time dependent) mapping including the function definition and the ### domain where the function is well define. This can be used to avoid interpolations out of range when mixing different time dependent data setsObjects from the Class
Objects can be created by calls of the form new(TimeMap ...)