Learn R Programming

SoilR (version 1.0-0)

TimeMap.from.Dataframe: TimeMap from Dataframe

Description

This function is another constructor of the class TimeMap.

Usage

TimeMap.from.Dataframe(dframe, interpolation = splinefun)

Arguments

dframe
A data frame containing exactly two columns: the first one is interpreted as time
interpolation
A function that returns a function the default is splinefun. Other possible values are the linear interpolation approxfun or any self made function with the same interface.

Value

  • An object of class TimeMap that contains the interpolation function and the limits of the time range where the function is valid. this serves as a saveguard for Model which thus can check that all involved functions of time are actually defined for the times of interest