Rdocumentation
powered by
Learn R Programming
SoilR (version 1.0-3)
getMeanTransitTime: access to the mean transit time
Description
This function computes the Expected Value of the transit time by integrating the product of t and the TransitTimeDistributionDensity
Usage
getMeanTransitTime(object, inputDistribution)
Arguments
object
inputDistribution