Rdocumentation
powered by
Learn R Programming
SoilR (version 1.0-3)
getTotalReleaseFluxC14CRatio: access to the C release flux from the pools
Description
This function computes the $\frac{^{14}C}{C}$ ratio of the released C as funtion of time
Usage
getTotalReleaseFluxC14CRatio(object)
Arguments
object