getTransitTimeDistributionDensity: access to the transit time distribution
Description
This function computes the transit time distribution density for a given Decomposition Operator
by computing the output (respiration) of the system according to an instantaneous input.Usage
getTransitTimeDistributionDensity(object, inputDistribution,
times)Arguments
inputDistribution
to one!.
Details
Let $O(t)$ describe the overall output flux of the system.
One can imagine $O(t)$ as a weighted sum of previous inputs $I(t-T)$. The weights for
this summation are
described by the transit time distribution density $\psi(T)$ where $T$ is the
transit time, the time from entry to exit of a particle.
This is expressed by the following relation:
$O(t)=\int_0^\infty \psi(T) I(t-T) dT$
For an instantaneous input $I(t-T)=\delta(t-T)$ the transit time distribution density becomes
equal to the output of the system, the respiration rate.
we can therefore compute the transfer time distribution by applying our Decomposition Operator to an
instantaneous imput, which is realized by an inputrate of zero and startvalues of one.